@@ -8,11 +8,11 @@ from telethon import functions, types
 import pandas as pd
 import os
 import csv
-import time
 from tqdm import tqdm
 from math import cos, sin, atan2, sqrt, pi, radians, degrees
 from geopy.point import Point
 import datetime
+import time
 
 
 def map_move(lat, lon, distance, bearing):
@@ -124,7 +124,7 @@ def api_login(api_id, api_hash, session_name):
     return client
 
 
-def near_entity(client, data_path, move_num, start_index=0):
+def near_entity(client, data_path, sleep_seconds, move_num, start_index=0):
     date_record = pd.to_datetime("today").strftime("%Y-%m-%d_%H%M%S")
     path = 'save_near_entity/'
     filename1 = 'near_user_' + date_record + '.csv'
@@ -155,8 +155,6 @@ def near_entity(client, data_path, move_num, start_index=0):
          'channel_restriction_text2',
          'channel_info_json'))
 
-    time.sleep(1)
-
     def geo_entity(lat, lon, radius):
         result = client(functions.contacts.GetLocatedRequest(
             geo_point=types.InputGeoPoint(
@@ -246,14 +244,13 @@ def near_entity(client, data_path, move_num, start_index=0):
     lons = geo.lon.to_list()[start_index:move_num]
     for lat, lon in tqdm(zip(lats, lons), total=len(lats)):
         geo_entity(lat, lon, 500)
-        time.sleep(50)
+        time.sleep(sleep_seconds)
 
     fp1.close()
     fp2.close()
-    time.sleep(1)
 
 
-def near_entity_resume(client, data_path, data_path_user, data_path_channel, move_num):
+def near_entity_resume(client, data_path, data_path_user, data_path_channel, sleep_seconds, move_num):
     with open(data_path_user, 'rb') as f_u:
         for tail_u in f_u:
             pass  # locate the last line
@@ -283,7 +280,7 @@ def near_entity_resume(client, data_path, data_path_user, data_path_channel, mov
 
     print("continue to conduct near_entity() from index " + str(last_index + 1) + " of the data_path file")
     start_index = last_index + 1
-    near_entity(client, data_path, move_num=move_num + start_index, start_index=start_index)
+    near_entity(client, data_path, sleep_seconds, move_num=move_num + start_index, start_index=start_index)
 
 
 def dedup(data_path):
@@ -336,7 +333,6 @@ def keywords_search_channel(client, data_path_channel, keywords, date_time, afte
                          'channel_restriction_text1', 'channel_restriction_platform2', 'channel_restriction_reason2',
                          'channel_restriction_text2', 'error',
                          'group_info_json', 'chat_search_json', 'user_info_json'))
-        time.sleep(1)
 
         date_time = datetime.datetime.strptime(date_time, '%Y-%m-%d %H:%M:%S')
 
@@ -383,7 +379,7 @@ def keywords_search_channel(client, data_path_channel, keywords, date_time, afte
                 for q in keywords:
                     keyword = q
                     chat_search = client.iter_messages(group_id, search=q, offset_date=date_time, reverse=after_before)
-                    n = 0
+                    # n = 0
 
                     for chat in chat_search:
                         chat_search_json = chat.to_json()
@@ -569,10 +565,10 @@ def keywords_search_channel(client, data_path_channel, keywords, date_time, afte
                              channel_restriction_text1, channel_restriction_platform2,
                              channel_restriction_reason2, channel_restriction_text2, error,
                              group_info_json, chat_search_json, user_info_json))
-                        n = n + 1
-                        if (n % 1000) == 0:
-                            time.sleep(10)
-                            print("sleeping 10 seconds")
+                        # n = n + 1
+                        # if (n % 1000) == 0:
+                        # time.sleep(10)
+                        # print("sleeping 10 seconds")
 
             except Exception as e:
                 error = e
@@ -601,7 +597,6 @@ def keywords_search_channel(client, data_path_channel, keywords, date_time, afte
                 f_resume_all.write(record)
 
         fp.close()
-        time.sleep(1)
 
         print(str(len(group_pool)) + " channels have been collected!")
 
@@ -612,7 +607,6 @@ def keywords_search_channel(client, data_path_channel, keywords, date_time, afte
         if not os.path.exists(path):
             os.makedirs(path)
 
-        time.sleep(1)
         date_time = datetime.datetime.strptime(date_time, '%Y-%m-%d %H:%M:%S')
 
         if after_before == "after":
@@ -688,7 +682,7 @@ def keywords_search_channel(client, data_path_channel, keywords, date_time, afte
                 for q in keywords:
                     keyword = q
                     chat_search = client.iter_messages(group_id, search=q, offset_date=date_time, reverse=after_before)
-                    n = 0
+                    # n = 0
 
                     for chat in chat_search:
                         chat_search_json = chat.to_json()
@@ -874,10 +868,10 @@ def keywords_search_channel(client, data_path_channel, keywords, date_time, afte
                              channel_restriction_text1, channel_restriction_platform2,
                              channel_restriction_reason2, channel_restriction_text2, error,
                              group_info_json, chat_search_json, user_info_json))
-                        n = n + 1
-                        if (n % 1000) == 0:
-                            time.sleep(10)
-                            print("sleeping 10 seconds")
+                        # n = n + 1
+                        # if (n % 1000) == 0:
+                        # time.sleep(10)
+                        # print("sleeping 10 seconds")
 
             except Exception as e:
                 error = e
@@ -908,8 +902,6 @@ def keywords_search_channel(client, data_path_channel, keywords, date_time, afte
                     after_before) + '~ ' + str(save_mode)
                 f_resume.write(record)
 
-        time.sleep(1)
-
         print(str(len(group_pool)) + " channels have been collected!")
 
     else:
@@ -928,8 +920,13 @@ def keywords_search_channel_resume(client, data_path_resume):
         keywords = record[2]
         date_time = record[3]
         after_before = record[4]
+        if after_before== True:
+            after_before = "after"
+        elif after_before == False:
+            after_before = "before"
+        else:
+            print("resume file error due to the wrong after_before")
         save_mode = str(record[-1]).strip()
-        # print(lastID, data_path_keywords, keywords, date_time, after_before, save_mode)
 
     dfo = pd.read_csv(data_path_keywords)
     var = dfo[dfo.channel_id == lastID].index[0]
@@ -938,8 +935,8 @@ def keywords_search_channel_resume(client, data_path_resume):
     dfr.to_csv(new_file, index=False)
     keywords = eval(keywords)
     keywords_search_channel(client=client,
-                                data_path_channel=new_file,
-                                keywords=keywords,
-                                date_time=date_time,
-                                after_before=after_before,
-                                save_mode=save_mode)
+                            data_path_channel=new_file,
+                            keywords=keywords,
+                            date_time=date_time,
+                            after_before=after_before,
+                            save_mode=save_mode)
